==> fillets-ng-data_0.7.1.orig.tar.gz: fillets-ng-data-0.7.1/script/cabin2/dialogs_de.lua <==

dialogId("k1-pap-3xkruty", "font_parrot", "Crrruel, crrruel, crrruel Captain Silverrrr...")
dialogStr("Grrrausamer, grrrausamer Kapitän Silverrrr...")


dialogId("k1-pap-kruty", "font_parrot", "Crrruel Captain Silverrrr...")
dialogStr("Grrrausamer Kapitän Silverrrr...")


dialogId("k1-pap-kruci", "font_parrot", "Good grrrief!")
dialogStr("Du meine Güte!")


dialogId("k1-pap-problem", "font_parrot", "Trrricky prrroblem, isn`t it?")
dialogStr("Kniffeliges Prrroblem, oderrr?")


dialogId("k1-pap-sakris", "font_parrot", "Darrrn!")
dialogStr("Verrrflixt!")


dialogId("k1-pap-sucharek", "font_parrot", "Polly wants a crrracker!")
dialogStr("Bubi will ein Keks!")


dialogId("k1-pap-trhnisi", "font_parrot", "Beat it, sirrr...")
dialogStr("Verrrduften Sie...")


dialogId("ka2-v-nekde", "font_big", "Didn`t we see this somewhere already?")
dialogStr("Haben wir das nicht irgendwo schon mal gesehen?")


dialogId("ka2-m-kdepak", "font_small", "No, you`re wrong. This cabin is one hundred and forty four squares larger...")
dialogStr("Falsch. Diese Kajüte ist einhundertvierundvierzig Ecken größer...")


dialogId("ka2-v-papousek", "font_big", "Look at that parrot!!!")
dialogStr("Schau, der Papagei!!!")


dialogId("ka2-m-kostra", "font_small", "So what? It's a normal skeleton.")
dialogStr("Na und? Ein normales Skelett.")


dialogId("ka2-m-posledni", "font_small", "Can you see it? This room is almost the last in the row. Could this really be that treasure?")
dialogStr("Hast du gesehen? Das ist fast der letzte Raum. Könnte das wirklich der Schatz sein?")


dialogId("ka2-v-mapa0", "font_big", "And what would be in the other two?")
dialogStr("Und was ist dann in den anderen zwei?")


dialogId("ka2-v-mapa1", "font_big", "They told us clearly to find the map. Nobody mentioned treasure.")
dialogStr("Die haben uns eindeutig gesagt, dass wir die Karte finden sollen. Niemand hat einen Schatz erwähnt.")


dialogId("ka2-v-mapa2", "font_big", "Don`t be so annoying. The authors of the game would surely let the player know.")
dialogStr("Nerv nicht. Die Spieleschreiber würden es dem Spieler sicherlich sagen.")


dialogId("ka2-m-chapadlo", "font_small", "This octopus has unpleasantly knotted tentacles. I can`t fit between them.")
dialogStr("Dieser Krake hat ziemlich verknotete Fangarme. Da pass ich nicht dazwischen.")


dialogId("ka2-v-fik", "font_big", "... so what if we cut one off?!")
dialogStr("... und wenn wir einen abschneiden?!")


dialogId("ka2-v-napad", "font_big", "I am sorry, it was just an idea.")
dialogStr("Tschuldigung, war ja nur so eine Idee.")


dialogId("ka2-m-hej", "font_small", "Little octopus, couldn`t you move away a little bit, please?")
dialogStr("Kleiner Krake, kannst du bitte ein wenig zur Seite gehen?")


dialogId("ka2-m-diky", "font_small", "Hmm... thanks a lot.")
dialogStr("Hmm... vielen Dank.")


dialogId("ka2-v-kostry", "font_big", "Skeletons seem to be a favorite motif of this game authors.")
dialogStr("Skelette scheinen ein Lieblingsthema der Spieleschreiber zu sein.")


dialogId("ka2-m-patrne", "font_small", "Who are probably living on land. These skeletons are visible proof of their effort to stuff the ocean with all the things that don`t belong there.")
dialogStr("Die wahrscheinlich an Land leben. Diese Skelette sind der sichtbare Beweis für ihre Anstrengungen, das Meer mit all den Dingen vollzustopfen, die hier nicht hergehören.")


dialogId("ka2-v-myslet", "font_big", "Let`s try to think. Can`t we take our solution of that previous cabin and modify it a little?")
dialogStr("Lass uns nachdenken. Können wir nicht die Lösung aus der vorherigen Kajüte nehmen und ein wenig abändern?")


dialogId("ka2-m-tezko", "font_small", "Hmm... I don`t think so.")
dialogStr("Hmm... Ich glaube nicht.")


dialogId("ka2-m-svitit", "font_small", "So, let`s shed some light on it.")
dialogStr("So, lass uns ein wenig Licht ins Dunkel bringen.")


dialogId("ka2-v-hrbet", "font_big", "My back aches.")
dialogStr("Mein Rücken tut weh.")

==> fillets-ng-data_0.8.0.orig.tar.gz: fillets-ng-data-0.8.0/script/cabin2/dialogs_de.lua <==

dialogId("k1-pap-3xkruty", "font_parrot", "Crrruel, crrruel, crrruel Captain Silverrrr...")
dialogStr("Grrrausamer, grrrausamer Kapitän Silverrrr...")


dialogId("k1-pap-kruty", "font_parrot", "Crrruel Captain Silverrrr...")
dialogStr("Grrrausamer Kapitän Silverrrr...")


dialogId("k1-pap-kruci", "font_parrot", "Good grrrief!")
dialogStr("Du meine Güte!")


dialogId("k1-pap-problem", "font_parrot", "Trrricky prrroblem, isn’t it?")
dialogStr("Kniffeliges Prrroblem, oderrr?")


dialogId("k1-pap-sakris", "font_parrot", "Darrrn!")
dialogStr("Verrrflixt!")


dialogId("k1-pap-sucharek", "font_parrot", "Polly wants a crrracker!")
dialogStr("Bubi will ein Keks!")


dialogId("k1-pap-trhnisi", "font_parrot", "Beat it, sirrr...")
dialogStr("Verrrduften Sie...")


dialogId("ka2-v-nekde", "font_big", "Didn’t we see this somewhere already?")
dialogStr("Haben wir das nicht irgendwo schon mal gesehen?")


dialogId("ka2-m-kdepak", "font_small", "No, you’re wrong. This cabin is one hundred and forty four squares larger...")
dialogStr("Falsch. Diese Kajüte ist einhundertvierundvierzig Ecken größer...")


dialogId("ka2-v-papousek", "font_big", "Look at that parrot!!!")
dialogStr("Schau, der Papagei!!!")


dialogId("ka2-m-kostra", "font_small", "So what? It's a normal skeleton.")
dialogStr("Na und? Ein normales Skelett.")


dialogId("ka2-m-posledni", "font_small", "Can you see it? This room is almost the last in the row. Could this really be that treasure?")
dialogStr("Hast du gesehen? Das ist fast der letzte Raum. Könnte das wirklich der Schatz sein?")


dialogId("ka2-v-mapa0", "font_big", "And what would be in the other two?")
dialogStr("Und was ist dann in den anderen zwei?")


dialogId("ka2-v-mapa1", "font_big", "They told us clearly to find the map. Nobody mentioned treasure.")
dialogStr("Die haben uns eindeutig gesagt, dass wir die Karte finden sollen. Niemand hat einen Schatz erwähnt.")


dialogId("ka2-v-mapa2", "font_big", "Don’t be so annoying. The authors of the game would surely let the player know.")
dialogStr("Nerv nicht. Die Spieleschreiber würden es dem Spieler sicherlich sagen.")


dialogId("ka2-m-chapadlo", "font_small", "This octopus has unpleasantly knotted tentacles. I can’t fit between them.")
dialogStr("Dieser Krake hat ziemlich verknotete Fangarme. Da pass ich nicht dazwischen.")


dialogId("ka2-v-fik", "font_big", "... so what if we cut one off?!")
dialogStr("... und wenn wir einen abschneiden?!")


dialogId("ka2-v-napad", "font_big", "I am sorry, it was just an idea.")
dialogStr("Tschuldigung, war ja nur so eine Idee.")


dialogId("ka2-m-hej", "font_small", "Little octopus, couldn’t you move away a little bit, please?")
dialogStr("Kleiner Krake, kannst du bitte ein wenig zur Seite gehen?")


dialogId("ka2-m-diky", "font_small", "Hmm... thanks a lot.")
dialogStr("Hmm... vielen Dank.")


dialogId("ka2-v-kostry", "font_big", "Skeletons seem to be a favorite motif of this game authors.")
dialogStr("Skelette scheinen ein Lieblingsthema der Spieleschreiber zu sein.")


dialogId("ka2-m-patrne", "font_small", "Who are probably living on land. These skeletons are visible proof of their effort to stuff the ocean with all the things that don’t belong there.")
dialogStr("Die wahrscheinlich an Land leben. Diese Skelette sind der sichtbare Beweis für ihre Anstrengungen, das Meer mit all den Dingen vollzustopfen, die hier nicht hergehören.")


dialogId("ka2-v-myslet", "font_big", "Let’s try to think. Can’t we take our solution of that previous cabin and modify it a little?")
dialogStr("Lass uns nachdenken. Können wir nicht die Lösung aus der vorherigen Kajüte nehmen und ein wenig abändern?")


dialogId("ka2-m-tezko", "font_small", "Hmm... I don’t think so.")
dialogStr("Hmm... Ich glaube nicht.")


dialogId("ka2-m-svitit", "font_small", "So, let’s shed some light on it.")
dialogStr("So, lass uns ein wenig Licht ins Dunkel bringen.")


dialogId("ka2-v-hrbet", "font_big", "My back aches.")
dialogStr("Mein Rücken tut weh.")
